@@ -70,15 +70,23 @@ template Feed {..} render =
         : Element "id" Map.empty [NodeContent $ render feedLinkHome]
         : Element "author" Map.empty [NodeElement $ Element "name" Map.empty [NodeContent feedAuthor]]
         : map (flip entryTemplate render) feedEntries
+        ++
+        case feedLogo of
+            Nothing -> []
+            Just (route, _) -> [Element "logo" Map.empty [NodeContent $ render route]]
 
 entryTemplate :: FeedEntry url -> (url -> Text) -> Element
-entryTemplate FeedEntry {..} render = Element "entry" Map.empty $ map NodeElement
+entryTemplate FeedEntry {..} render = Element "entry" Map.empty $ map NodeElement $
     [ Element "id" Map.empty [NodeContent $ render feedEntryLink]
     , Element "link" (Map.singleton "href" $ render feedEntryLink) []
     , Element "updated" Map.empty [NodeContent $ formatW3 feedEntryUpdated]
     , Element "title" Map.empty [NodeContent feedEntryTitle]
     , Element "content" (Map.singleton "type" "html") [NodeContent $ toStrict $ renderHtml feedEntryContent]
     ]
+    ++
+    case feedEntryEnclosure of
+        Nothing -> []
+        Just (route, _, _) -> [Element "link" (Map.fromList [("rel", "enclosure"), ("href", render route)]) []]
 
 -- | Generates a link tag in the head of a widget.
 atomLink :: MonadWidget m
